package
Version:
v0.1.2
Opens a new window with list of versions in this module.
Published: Apr 11, 2026
License: MIT
Opens a new window with license information.
Imports: 18
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
RunConfig launches the TUI configuration interface.
func RunStatusline() error
RunStatusline is the main pipeline: read stdin, fetch data, render, output.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.